==> fillets-ng-data_0.7.1.orig.tar.gz: fillets-ng-data-0.7.1/script/tank/dialogs_nl.lua <==

dialogId("sv-m-pomohli", "font_small", "This is some improvement. From bathyscaph to tank, this is like from a line into a net.")
dialogStr("Dit is een stuk beter. Van mini-onderzeeër naar tank, van de regen in de drup.")


dialogId("sv-v-bezsneku", "font_big", "At least there are no oh-so-obliging snails here.")
dialogStr("Gelukkig zijn hier geen slijmerige slakken.")


dialogId("sv-m-utecha", "font_small", "That is but little consolation.")
dialogStr("Dat is een schale troost.")


dialogId("sv-v-chtel", "font_big", "Thinking about it, I always wanted to see the inside of a tank.")
dialogStr("Nu ik erover nadenk, ik wilde altijd al een keertje de binnenkant van een tank bekijken.")


dialogId("sv-m-doscasu", "font_small", "It seems you will have plenty of opportunity to look around.")
dialogStr("Nu heb je de kans hebt om eens flink rond te kijken.")


dialogId("sv-m-tank", "font_small", "I wonder how this tank got into the sea.")
dialogStr("Hoe zou deze tank in de zee terecht zijn gekomen?")


dialogId("sv-v-obojzivelny", "font_big", "Maybe it was an amphibious tank.")
dialogStr("Misschien was het een amfibievoertuig.")


dialogId("sv-m-kecy", "font_small", "An amphibious tank? Just imagine: On the moonless night, the uncomprehending defenders bewilderedly watch the mass of snorkels emerging from the surf, searching in vain for the landing craft...")
dialogStr("Een amfibievoertuig? Stel je voor: Het is nieuwe maan, de verbouwereerde verdedigers zien een bos van snorkels uit de golven omhoog prikken en vragen zich verbaasd af waar het landingsvoertuig is...")


dialogId("sv-v-proc", "font_big", "So why are you asking, if you are so darned clever?!")
dialogStr("Waarom vraag je het dan, als je zelf zo slim bent?!")


dialogId("sv-v-potopena", "font_big", "Maybe there is a sunken landing craft nearby.")
dialogStr("Misschien is het gezonken landingsvoertuig in de buurt.")


dialogId("sv-m-pravdepodob", "font_small", "It is possible.")
dialogStr("Niets is onmogelijk.")


dialogId("sv-m-munice", "font_small", "Do you think that this ammunition could harm us?")
dialogStr("Denk je dat deze munitie nog gevaarlijk is?")


dialogId("sv-v-nevim", "font_big", "I don`t know, but I`ll try to keep my distance from it.")
dialogStr("Ik weet het niet, maar ik probeer wel een beetje afstand te houde.")


dialogId("sv-v-zebrik", "font_big", "I think we are going to need that ladder.")
dialogStr("Ik denk dat we die ladder nodig gaan hebben.")


dialogId("sv-m-ven", "font_small", "To climb out? But we have only fins.")
dialogStr("Om hier uit te klimmen? Maar we hebben alleen maar vinnen.")


dialogId("sv-v-ucpat", "font_big", "No. To plug that hole.")
dialogStr("Nee. Om dat gat dicht te stoppen.")

==> fillets-ng-data_1.0.0.orig.tar.gz: fillets-ng-data-1.0.0/script/tank/dialogs_nl.lua <==

dialogId("sv-m-pomohli", "font_small", "This is some improvement. From bathyscaph to tank, this is like from a line into a net.")
dialogStr("Dit is een stuk beter. Van bathyscaaf naar tank, van de regen in de drup.")


dialogId("sv-v-bezsneku", "font_big", "At least there are no oh-so-obliging snails here.")
dialogStr("Gelukkig zijn hier geen slijmerige slakken.")


dialogId("sv-m-utecha", "font_small", "That is but little consolation.")
dialogStr("Dat is een schale troost.")


dialogId("sv-v-chtel", "font_big", "Thinking about it, I always wanted to see the inside of a tank.")
dialogStr("Ik realiseer me net dat ik altijd al een keertje de binnenkant van een tank heb willen zien.")


dialogId("sv-m-doscasu", "font_small", "It seems you will have plenty of opportunity to look around.")
dialogStr("Nu heb je de kans om eens flink rond te kijken.")


dialogId("sv-m-tank", "font_small", "I wonder how this tank got into the sea.")
dialogStr("Hoe zou deze tank in zee terecht zijn gekomen?")


dialogId("sv-v-obojzivelny", "font_big", "Maybe it was an amphibious tank.")
dialogStr("Misschien was het een amfibievoertuig.")


dialogId("sv-m-kecy", "font_small", "An amphibious tank? Just imagine: On the moonless night, the uncomprehending defenders bewilderedly watch the mass of snorkels emerging from the surf, searching in vain for the landing craft...")
dialogStr("Een amfibievoertuig? Stel je voor: Het is nieuwe maan, de verbouwereerde verdedigers zien een bos snorkels uit de golven omhoog prikken en vragen zich verbaasd af waar het landingsvoertuig is...")


dialogId("sv-v-proc", "font_big", "So why are you asking, if you are so darned clever?!")
dialogStr("Waarom vraag je het dan, als je het zelf allemaal zo goed weet?!")


dialogId("sv-v-potopena", "font_big", "Maybe there is a sunken landing craft nearby.")
dialogStr("Misschien is het gezonken landingsvoertuig in de buurt.")


dialogId("sv-m-pravdepodob", "font_small", "It is possible.")
dialogStr("Niets is onmogelijk.")


dialogId("sv-m-munice", "font_small", "Do you think that this ammunition could harm us?")
dialogStr("Denk je dat deze munitie nog gevaarlijk is?")


dialogId("sv-v-nevim", "font_big", "I don’t know, but I’ll try to keep my distance from it.")
dialogStr("Ik weet het niet, maar ik probeer wel een beetje afstand te houden.")


dialogId("sv-v-zebrik", "font_big", "I think we are going to need that ladder.")
dialogStr("Ik denk dat we die ladder nodig gaan hebben.")


dialogId("sv-m-ven", "font_small", "To climb out? But we have only fins.")
dialogStr("Om hier uit te klimmen? Maar we hebben alleen maar vinnen.")


dialogId("sv-v-ucpat", "font_big", "No. To plug that hole.")
dialogStr("Nee. Om dat gat dicht te stoppen.")
